{
 "metadata": {
  "name": ""
 },
 "nbformat": 3,
 "nbformat_minor": 0,
 "worksheets": [
  {
   "cells": [
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "# Adding new objects to Nengo\n",
      "\n",
      "It is possible to add new objects\n",
      "to the Nengo reference simulator.\n",
      "This involves several steps and the creation\n",
      "of several objects.\n",
      "In this example, we'll go through these steps\n",
      "in order to add a new neuron type to Nengo:\n",
      "a rectified linear neuron.\n",
      "\n",
      "## Step 1: Create a frontend Neurons subclass\n",
      "\n",
      "The `RectifiedLinear` class is what you will use\n",
      "in model scripts to denote that a particular ensemble\n",
      "should be simulated using a rectified linear neuron\n",
      "instead of one of the existing neuron types (e.g., `LIF`).\n",
      "\n",
      "Normally, these kinds of frontend classes exist\n",
      "in either `nengo/objects.py` or `nengo/neurons.py`.\n",
      "Look at these files for examples of how to make your own.\n",
      "In this case, becuase we're making a neuron type,\n",
      "we'll use `nengo.neurons.LIF` as an example\n",
      "of how to make `RectifiedLinear`."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "import numpy as np\n",
      "import matplotlib.pyplot as plt\n",
      "%matplotlib inline\n",
      "\n",
      "import nengo\n",
      "%load_ext nengo.ipynb\n",
      "\n",
      "class RectifiedLinear(nengo.neurons.NeuronType):  # Neuron types must subclass `nengo.Neurons`\n",
      "    \"\"\"A rectified linear neuron model.\"\"\"\n",
      "    \n",
      "    # We don't need any additional parameters here;\n",
      "    # gain and bias are sufficient. But, if we wanted\n",
      "    # more parameters, we could accept them by creating\n",
      "    # an __init__ method.\n",
      "    \n",
      "    def gain_bias(self, max_rates, intercepts):\n",
      "        \"\"\"Return gain and bias given maximum firing rate and x-intercept.\"\"\"\n",
      "        gain = max_rates / (1 - intercepts)\n",
      "        bias = -intercepts * gain\n",
      "        return gain, bias\n",
      "\n",
      "    def step_math(self, dt, J, output):\n",
      "        \"\"\"Compute rates in Hz for input current (incl. bias)\"\"\"\n",
      "        output[...] = np.maximum(0., J)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "text": [
        "<IPython.core.display.Javascript at 0x7f0e1dcda250>"
       ]
      }
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## Step 2: Create a backend Operator subclass\n",
      "\n",
      "The `Operator` (located in `nengo/builder.py`) defines\n",
      "the function that the reference simulator will execute\n",
      "on every timestep. Most new neuron types and learning rules\n",
      "will require a new `Operator`, unless the function\n",
      "being computed can be done by combining several\n",
      "existing operators.\n",
      "\n",
      "In this case, we will make a new operator\n",
      "that outputs the firing rate of each neuron\n",
      "on every timestep.\n",
      "\n",
      "Note that for neuron types specifically,\n",
      "there is a `SimNeurons` operator that\n",
      "calls `step_math`. However, we will\n",
      "implement a new operator here to demonstrate\n",
      "how to build a simple operator."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "from nengo.builder.operator import Operator\n",
      "\n",
      "class SimRectifiedLinear(Operator):\n",
      "    \"\"\"Set output to the firing rate of a rectified linear neuron model.\"\"\"\n",
      "    \n",
      "    def __init__(self, output, J, neurons):\n",
      "        self.output = output  # Output signal of the ensemble\n",
      "        self.J = J  # Input current from the ensmble\n",
      "        self.neurons = neurons  # The RectifiedLinear instance\n",
      "        \n",
      "        # Operators must explicitly tell the simulator what signals\n",
      "        # they read, set, update, and increment\n",
      "        self.reads = [J]\n",
      "        self.updates = [output]\n",
      "        self.sets = []\n",
      "        self.incs = []\n",
      "        \n",
      "    # If we needed additional signals that aren't in one of the\n",
      "    # reads, updates, sets, or incs lists, we can initialize them\n",
      "    # by making an `init_signals(self, signals, dt)` method.\n",
      "    \n",
      "    def make_step(self, signals, dt, rng):\n",
      "        \"\"\"Return a function that the Simulator will execute on each step.\n",
      "        \n",
      "        `signals` contains a dictionary mapping each signal to\n",
      "        an ndarray which can be used in the step function.\n",
      "        `dt` is the simulator timestep (which we don't use).\n",
      "        \"\"\"\n",
      "        J = signals[self.J]\n",
      "        output = signals[self.output]\n",
      "        def step_simrectifiedlinear():\n",
      "            # Gain and bias are already taken into account here,\n",
      "            # so we just need to rectify\n",
      "            output[...] = np.maximum(0, J)\n",
      "        return step_simrectifiedlinear"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 2
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## Step 3: Create a build function\n",
      "\n",
      "In order for `nengo.builder.Builder`\n",
      "to construct signals and operators\n",
      "for the Simulator to use,\n",
      "you must create and register a build function\n",
      "with `nengo.builder.Builder`.\n",
      "This function should take as arguments\n",
      "a `RectifiedLinear` instance,\n",
      "some other arguments specific to the type,\n",
      "and a `nengo.builder.Model` instance.\n",
      "The function should add the approrpiate\n",
      "signals, operators, and other artifacts\n",
      "to the `Model` instance,\n",
      "and then register the build function\n",
      "with `nengo.builder.Builder`."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "from nengo.builder import Builder\n",
      "from nengo.builder.operator import Copy\n",
      "from nengo.builder.signal import Signal\n",
      "\n",
      "@Builder.register(RectifiedLinear)\n",
      "def build_rectified_linear(model, neuron_type, neurons):\n",
      "    model.operators.append(SimRectifiedLinear(\n",
      "        output=model.sig[neurons]['out'], J=model.sig[neurons]['in'], neurons=neuron_type))\n"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 3
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Now you can use `RectifiedLinear` like any other neuron type!\n",
      "\n",
      "# Tuning curves\n",
      "\n",
      "We can build a small network just to see the tuning curves."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "from nengo.utils.ensemble import tuning_curves\n",
      "\n",
      "model = nengo.Network()\n",
      "with model:\n",
      "    encoders = np.tile([[1],[-1]], (4,1))\n",
      "    intercepts = np.linspace(-0.8, 0.8, 8)\n",
      "    intercepts *= encoders[:,0]\n",
      "    A = nengo.Ensemble(8, dimensions=1, intercepts=intercepts, neuron_type=RectifiedLinear(),\n",
      "                       max_rates=nengo.dists.Uniform(80, 100),\n",
      "                       encoders=encoders)\n",
      "with nengo.Simulator(model) as sim:\n",
      "    eval_points, activities = tuning_curves(A, sim)\n",
      "plt.plot(eval_points, activities, lw=2)\n",
      "plt.xlabel(\"Input signal\")\n",
      "plt.ylabel(\"Firing rate (Hz)\");"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAYsAAAEPCAYAAACzwehFAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nAABJRU5ErkJggg==\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f0de5e61350>"
       ]
      }
     ],
     "prompt_number": 4
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## 2D Representation example\n",
      "\n",
      "Below is the same model as is made in the 2d_representation example,\n",
      "except now using `RectifiedLinear` neurons insated of `nengo.LIF`."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "model = nengo.Network(label='2D Representation', seed=10)\n",
      "with model:\n",
      "    neurons = nengo.Ensemble(100, dimensions=2, neuron_type=RectifiedLinear())\n",
      "    sin = nengo.Node(output=np.sin)\n",
      "    cos = nengo.Node(output=np.cos)\n",
      "    nengo.Connection(sin, neurons[0])\n",
      "    nengo.Connection(cos, neurons[1])\n",
      "    sin_probe = nengo.Probe(sin, 'output')\n",
      "    cos_probe = nengo.Probe(cos, 'output')\n",
      "    neurons_probe = nengo.Probe(neurons, 'decoded_output', synapse=0.01)\n",
      "with nengo.Simulator(model) as sim:\n",
      "    sim.run(5)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 5
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "plt.plot(sim.trange(), sim.data[neurons_probe], label=\"Decoded output\")\n",
      "plt.plot(sim.trange(), sim.data[sin_probe], 'r', label=\"Sine\")\n",
      "plt.plot(sim.trange(), sim.data[cos_probe], 'k', label=\"Cosine\")\n",
      "plt.legend();"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAEACAYAAACwB81wAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f0de5ec8610>"
       ]
      }
     ],
     "prompt_number": 6
    }
   ],
   "metadata": {}
  }
 ]
}